/* $Id: ast_compound.cpp 6310 2023-01-16 20:39:48Z aron $ */
/*
    Welltype parser and AST
    Copyright (C) 2014-2023  Aron Barath

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/

#include "ast_compound.h"
#include "ast_statement.h"
#include "../astvisitor.h"

wtast::Compound::~Compound()
{
	while(!mStatements.empty())
	{
		delete mStatements.front();
		mStatements.pop_front();
	}
}

void wtast::Compound::Accept(AstVisitor* vis)
{
	if(vis->Visit(this))
	{
		for(statements_t::iterator it=mStatements.begin(),end=mStatements.end();it!=end;++it)
		{
			(*it)->Accept(vis);
		}

		vis->EndVisit(this);
	}
}

wtast::Compound* wtast::Compound::Copy()
{
	statements_t copies;

	for(statements_t::iterator it=mStatements.begin(),end=mStatements.end();it!=end;++it)
	{
		copies.push_back((*it)->Copy());
	}

	return new Compound(copies.begin(), copies.end(), mName);
}
