/* $Id: ast_mainblock.cpp 6310 2023-01-16 20:39:48Z aron $ */
/*
    Welltype parser and AST
    Copyright (C) 2014-2023  Aron Barath

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/

#include "ast_mainblock.h"
#include "ast_exceptioncompound.h"
#include "../astvisitor.h"

wtast::MainBlock::MainBlock(ExceptionCompound* ec, wt_u32 css, wt_u32 dss)
	: Block()
	, mBody(ec)
	, mCSS(css)
	, mDSS(dss)
{
	if(0==mCSS)
	{
		mCSS = 0x2000; // TODO
	}

	if(0==mDSS)
	{
		mDSS = 0x800; // TODO
	}
}

wtast::MainBlock::~MainBlock()
{
	delete mBody;
}

void wtast::MainBlock::Accept(AstVisitor* vis)
{
	if(vis->Visit(this))
	{
		mBody->Accept(vis);
		vis->EndVisit(this);
	}
}

wtast::MainBlock* wtast::MainBlock::Copy()
{
	return new MainBlock(mBody->Copy(), mCSS, mDSS);
}
