//================================================================================================
// $Id: frontend.cpp 6309 2023-01-16 20:19:42Z aron $
//
// Project:
//		Welltype Parser
// Contents:
//		Parser frontend
// Authors:
//		Aron Barath, 2014-2023
//================================================================================================
// Copyright (c) Aron Barath
//================================================================================================

#include "frontend.h"
#include "ParserHelper.h"
#include "parser.tab.hpp"
#include "lex.yy.cc.h"
#include "ast/ast_program.h"

namespace wtparser
{

wtast::Program* Parse(const std::string & filename, ISourceManager* sm, IProblemHandler* ph, const IOptions* opt)
{
	wtast::Program* program = 0;
	WTParser*       parser  = 0;

	if(!sm || !ph || !opt)
	{
		return 0;
	}

	ParserHelper helper(sm, ph, opt);

	if(0!=(parser=new WTParser(helper)))
	{
		if(helper.Init(filename) && 0==parser->parse())
		{
			program = helper.GetProgram();
		}

		delete parser;
	}

	return program;
}

} // namespace wtparser

